==> mojo_config-0.0.17.tar.gz: mojo_config-0.0.17/source/packages/mojo/config/variables.py <==
"""
.. module:: varnames
    :platform: Darwin, Linux, Unix, Windows
    :synopsis: Module that contains an enumeration of environment variable names
               that are used by the configuration code.

.. moduleauthor:: Myron Walker <myron.walker@gmail.com>
"""


import os

from mojo.collections.wellknown import ContextSingleton

from mojo.config.normalize import (
    split_and_normalize_name_list,
    split_and_normalize_path_list,
    split_and_normalize_source_list
)
from mojo.config.overrides import MOJO_CONFIG_OVERRIDES


class MOJO_CONFIG_VARNAMES:

    MJR_NAME = "MJR_NAME"

    MJR_HOME_DIRECTORY = "MJR_HOME_DIRECTORY"

    MJR_CONFIG_DIRECTORY = "MJR_CONFIG_DIRECTORY"

    MJR_CONFIG_PASS_PHRASE = "MJR_CONFIG_PASS_PHRASE"

    MJR_CONFIG_CREDENTIAL_NAMES = "MJR_CONFIG_CREDENTIAL_NAMES"
    MJR_CONFIG_CREDENTIAL_URIS = "MJR_CONFIG_CREDENTIAL_URIS"
    MJR_CONFIG_CREDENTIAL_SOURCES = "MJR_CONFIG_CREDENTIAL_SOURCES"
    MJR_CONFIG_CREDENTIAL_FILES = "MJR_CONFIG_CREDENTIAL_FILES"

    MJR_CONFIG_LANDSCAPE_NAMES = "MJR_CONFIG_LANDSCAPE_NAMES"
    MJR_CONFIG_LANDSCAPE_URIS = "MJR_CONFIG_LANDSCAPE_URIS"
    MJR_CONFIG_LANDSCAPE_SOURCES = "MJR_CONFIG_LANDSCAPE_SOURCES"
    MJR_CONFIG_LANDSCAPE_FILES = "MJR_CONFIG_LANDSCAPE_FILES"

    MJR_CONFIG_TOPOLOGY_NAMES = "MJR_CONFIG_TOPOLOGY_NAMES"
    MJR_CONFIG_TOPOLOGY_URIS = "MJR_CONFIG_TOPOLOGY_URIS"
    MJR_CONFIG_TOPOLOGY_SOURCES = "MJR_CONFIG_TOPOLOGY_SOURCES"
    MJR_CONFIG_TOPOLOGY_FILES = "MJR_CONFIG_TOPOLOGY_FILES"

    MJR_CONFIG_RUNTIME_NAMES = "MJR_CONFIG_RUNTIME_NAMES"
    MJR_CONFIG_RUNTIME_URIS = "MJR_CONFIG_RUNTIME_URIS"
    MJR_CONFIG_RUNTIME_SOURCES = "MJR_CONFIG_RUNTIME_SOURCES"
    MJR_CONFIG_RUNTIME_FILES = "MJR_CONFIG_RUNTIME_FILES"


class MOJO_CONFIG_VARIABLES:

    MJR_NAME = MOJO_CONFIG_OVERRIDES.MJR_NAME

    MJR_HOME_DIRECTORY = os.path.expanduser("~/{}".format(MJR_NAME))

    MJR_CONFIG_REQUIRE_CREDENTIALS = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_CREDENTIALS
    MJR_CONFIG_REQUIRE_LANDSCAPE = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_LANDSCAPE
    MJR_CONFIG_REQUIRE_RUNTIME = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_RUNTIME
    MJR_CONFIG_REQUIRE_TOPOLOGY = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_TOPOLOGY

    MJR_CONFIG_USE_CREDENTIALS = False
    MJR_CONFIG_USE_LANDSCAPE = False
    MJR_CONFIG_USE_RUNTIME = False
    MJR_CONFIG_USE_TOPOLOGY = False

    MJR_CONFIG_DIRECTORY = os.path.join(MJR_HOME_DIRECTORY, "config")

    MJR_CONFIG_PASS_PHRASE = None

    MJR_CONFIG_CREDENTIAL_NAMES = None
    MJR_CONFIG_CREDENTIAL_URIS = None
    MJR_CONFIG_CREDENTIAL_SOURCES = None
    MJR_CONFIG_CREDENTIAL_FILES = None

    MJR_CONFIG_LANDSCAPE_NAMES = None
    MJR_CONFIG_LANDSCAPE_URIS = None
    MJR_CONFIG_LANDSCAPE_SOURCES = None
    MJR_CONFIG_LANDSCAPE_FILES = None

    MJR_CONFIG_TOPOLOGY_NAMES = None
    MJR_CONFIG_TOPOLOGY_URIS = None
    MJR_CONFIG_TOPOLOGY_SOURCES = None
    MJR_CONFIG_TOPOLOGY_FILES = None

    MJR_CONFIG_RUNTIME_NAMES = None
    MJR_CONFIG_RUNTIME_URIS = None
    MJR_CONFIG_RUNTIME_SOURCES = None
    MJR_CONFIG_RUNTIME_FILES = None


def resolve_configuration_variables():

    environ = os.environ

    ctx = ContextSingleton()

    MOJO_CONFIG_VARIABLES.MJR_HOME_DIRECTORY = MOJO_CONFIG_OVERRIDES.MJR_HOME_DIRECTORY
    if MOJO_CONFIG_VARNAMES.MJR_HOME_DIRECTORY in environ:
        MOJO_CONFIG_VARIABLES.MJR_HOME_DIRECTORY = environ[MOJO_CONFIG_VARNAMES.MJR_HOME_DIRECTORY]

    MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY = os.path.join(MOJO_CONFIG_VARIABLES.MJR_HOME_DIRECTORY, "config")
    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_DIRECTORY in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY = environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_DIRECTORY]

    # ====================== PROCESS CREDENTIAL VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_CREDENTIALS = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_CREDENTIALS = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_CREDENTIALS and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_CREDENTIALS = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_NAMES = ["credentials"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_SOURCES = [os.path.join(MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY)]

    # ====================== PROCESS LANDSCAPE VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_LANDSCAPE = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_LANDSCAPE = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_LANDSCAPE and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_LANDSCAPE = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_NAMES = ["default-landscape"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_SOURCES = [os.path.join(
            MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY, "landscapes")]

    # ====================== PROCESS RUNTIME VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_RUNTIME and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_NAMES = ["default-runtime"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_SOURCES = [os.path.join(
            MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY, "runtimes")]

    # ====================== PROCESS TOPOLOGY VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_TOPOLOGY = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_TOPOLOGY = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_RUNTIME and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_NAMES = ["default-topology"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_SOURCES = [os.path.join(
            MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY, "topologies")]

    return

==> mojo_config-0.0.22.tar.gz: mojo_config-0.0.22/source/packages/mojo/config/variables.py <==
"""
.. module:: varnames
    :platform: Darwin, Linux, Unix, Windows
    :synopsis: Module that contains an enumeration of environment variable names
               that are used by the configuration code.

.. moduleauthor:: Myron Walker <myron.walker@gmail.com>
"""


import os

from mojo.collections.wellknown import ContextSingleton

from mojo.config.normalize import (
    split_and_normalize_name_list,
    split_and_normalize_path_list,
    split_and_normalize_source_list
)
from mojo.config.overrides import MOJO_CONFIG_OVERRIDES


class MOJO_CONFIG_VARNAMES:

    MJR_NAME = "MJR_NAME"

    MJR_HOME_DIRECTORY = "MJR_HOME_DIRECTORY"

    MJR_CONFIG_DIRECTORY = "MJR_CONFIG_DIRECTORY"

    MJR_CONFIG_PASS_PHRASE = "MJR_CONFIG_PASS_PHRASE"

    MJR_CONFIG_CREDENTIAL_NAMES = "MJR_CONFIG_CREDENTIAL_NAMES"
    MJR_CONFIG_CREDENTIAL_URIS = "MJR_CONFIG_CREDENTIAL_URIS"
    MJR_CONFIG_CREDENTIAL_SOURCES = "MJR_CONFIG_CREDENTIAL_SOURCES"
    MJR_CONFIG_CREDENTIAL_FILES = "MJR_CONFIG_CREDENTIAL_FILES"

    MJR_CONFIG_LANDSCAPE_NAMES = "MJR_CONFIG_LANDSCAPE_NAMES"
    MJR_CONFIG_LANDSCAPE_URIS = "MJR_CONFIG_LANDSCAPE_URIS"
    MJR_CONFIG_LANDSCAPE_SOURCES = "MJR_CONFIG_LANDSCAPE_SOURCES"
    MJR_CONFIG_LANDSCAPE_FILES = "MJR_CONFIG_LANDSCAPE_FILES"

    MJR_CONFIG_TOPOLOGY_NAMES = "MJR_CONFIG_TOPOLOGY_NAMES"
    MJR_CONFIG_TOPOLOGY_URIS = "MJR_CONFIG_TOPOLOGY_URIS"
    MJR_CONFIG_TOPOLOGY_SOURCES = "MJR_CONFIG_TOPOLOGY_SOURCES"
    MJR_CONFIG_TOPOLOGY_FILES = "MJR_CONFIG_TOPOLOGY_FILES"

    MJR_CONFIG_RUNTIME_NAMES = "MJR_CONFIG_RUNTIME_NAMES"
    MJR_CONFIG_RUNTIME_URIS = "MJR_CONFIG_RUNTIME_URIS"
    MJR_CONFIG_RUNTIME_SOURCES = "MJR_CONFIG_RUNTIME_SOURCES"
    MJR_CONFIG_RUNTIME_FILES = "MJR_CONFIG_RUNTIME_FILES"


class MOJO_CONFIG_VARIABLES:

    # Don't override these until we resolve variables.
    MJR_NAME = "mjr"
    MJR_HOME_DIRECTORY = os.path.join(os.path.expanduser("~/"), MJR_NAME)

    MJR_CONFIG_REQUIRE_CREDENTIALS = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_CREDENTIALS
    MJR_CONFIG_REQUIRE_LANDSCAPE = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_LANDSCAPE
    MJR_CONFIG_REQUIRE_RUNTIME = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_RUNTIME
    MJR_CONFIG_REQUIRE_TOPOLOGY = MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_TOPOLOGY

    MJR_CONFIG_USE_CREDENTIALS = False
    MJR_CONFIG_USE_LANDSCAPE = False
    MJR_CONFIG_USE_RUNTIME = False
    MJR_CONFIG_USE_TOPOLOGY = False

    MJR_CONFIG_DIRECTORY = os.path.join(MJR_HOME_DIRECTORY, "config")

    MJR_CONFIG_PASS_PHRASE = None

    MJR_CONFIG_CREDENTIAL_NAMES = None
    MJR_CONFIG_CREDENTIAL_URIS = None
    MJR_CONFIG_CREDENTIAL_SOURCES = None
    MJR_CONFIG_CREDENTIAL_FILES = None

    MJR_CONFIG_LANDSCAPE_NAMES = None
    MJR_CONFIG_LANDSCAPE_URIS = None
    MJR_CONFIG_LANDSCAPE_SOURCES = None
    MJR_CONFIG_LANDSCAPE_FILES = None

    MJR_CONFIG_TOPOLOGY_NAMES = None
    MJR_CONFIG_TOPOLOGY_URIS = None
    MJR_CONFIG_TOPOLOGY_SOURCES = None
    MJR_CONFIG_TOPOLOGY_FILES = None

    MJR_CONFIG_RUNTIME_NAMES = None
    MJR_CONFIG_RUNTIME_URIS = None
    MJR_CONFIG_RUNTIME_SOURCES = None
    MJR_CONFIG_RUNTIME_FILES = None


def resolve_configuration_variables():

    environ = os.environ

    ctx = ContextSingleton()

    MOJO_CONFIG_VARIABLES.MJR_NAME = MOJO_CONFIG_OVERRIDES.MJR_NAME
    MOJO_CONFIG_VARIABLES.MJR_HOME_DIRECTORY = os.path.expandvars(os.path.expanduser(MOJO_CONFIG_OVERRIDES.MJR_HOME_DIRECTORY))

    if MOJO_CONFIG_VARNAMES.MJR_HOME_DIRECTORY in environ:
        MOJO_CONFIG_VARIABLES.MJR_HOME_DIRECTORY = environ[MOJO_CONFIG_VARNAMES.MJR_HOME_DIRECTORY]

    MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY = os.path.join(MOJO_CONFIG_VARIABLES.MJR_HOME_DIRECTORY, "config")
    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_DIRECTORY in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY = environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_DIRECTORY]

    # ====================== PROCESS CREDENTIAL VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_CREDENTIALS = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_CREDENTIALS = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_CREDENTIALS and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_CREDENTIALS = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_NAMES = ["credentials"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_CREDENTIAL_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_CREDENTIAL_SOURCES = [os.path.join(MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY)]

    # ====================== PROCESS LANDSCAPE VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_LANDSCAPE = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_LANDSCAPE = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_LANDSCAPE and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_LANDSCAPE = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_NAMES = ["default-landscape"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_LANDSCAPE_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_LANDSCAPE_SOURCES = [os.path.join(
            MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY, "landscapes")]

    # ====================== PROCESS RUNTIME VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_RUNTIME and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_NAMES = ["default-runtime"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_RUNTIME_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_SOURCES = [os.path.join(
            MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY, "runtimes")]

    # ====================== PROCESS TOPOLOGY VARIABLES ==============================

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_FILES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_TOPOLOGY = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_FILES = split_and_normalize_path_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_FILES])

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_NAMES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_TOPOLOGY = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_NAMES = split_and_normalize_name_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_NAMES])
    elif MOJO_CONFIG_OVERRIDES.MJR_CONFIG_REQUIRE_RUNTIME and not MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_FILES:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_USE_RUNTIME = True
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_RUNTIME_NAMES = ["default-topology"]

    if MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_SOURCES in environ:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_SOURCES = split_and_normalize_source_list(
            environ[MOJO_CONFIG_VARNAMES.MJR_CONFIG_TOPOLOGY_SOURCES])
    else:
        MOJO_CONFIG_VARIABLES.MJR_CONFIG_TOPOLOGY_SOURCES = [os.path.join(
            MOJO_CONFIG_VARIABLES.MJR_CONFIG_DIRECTORY, "topologies")]

    return
